==> kubernetes-model-apps-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/apps/ControllerRevisionBuilder.java <==
package io.fabric8.kubernetes.api.model.apps;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ControllerRevisionBuilder extends ControllerRevisionFluentImpl<ControllerRevisionBuilder> implements VisitableBuilder<ControllerRevision,ControllerRevisionBuilder>{
  public ControllerRevisionBuilder() {
    this(false);
  }
  public ControllerRevisionBuilder(Boolean validationEnabled) {
    this(new ControllerRevision(), validationEnabled);
  }
  public ControllerRevisionBuilder(ControllerRevisionFluent<?> fluent) {
    this(fluent, false);
  }
  public ControllerRevisionBuilder(ControllerRevisionFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ControllerRevision(), validationEnabled);
  }
  public ControllerRevisionBuilder(ControllerRevisionFluent<?> fluent,ControllerRevision instance) {
    this(fluent, instance, false);
  }
  public ControllerRevisionBuilder(ControllerRevisionFluent<?> fluent,ControllerRevision instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withData(instance.getData());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withRevision(instance.getRevision());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ControllerRevisionBuilder(ControllerRevision instance) {
    this(instance,false);
  }
  public ControllerRevisionBuilder(ControllerRevision instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withData(instance.getData());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withRevision(instance.getRevision());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  ControllerRevisionFluent<?> fluent;
  Boolean validationEnabled;
  public ControllerRevision build() {
    ControllerRevision buildable = new ControllerRevision(fluent.getApiVersion(),fluent.getData(),fluent.getKind(),fluent.getMetadata(),fluent.getRevision());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> kubernetes-model-apps-6.8.1-sources.jar: io/fabric8/kubernetes/api/model/apps/ControllerRevisionBuilder.java <==
package io.fabric8.kubernetes.api.model.apps;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ControllerRevisionBuilder extends ControllerRevisionFluent<ControllerRevisionBuilder> implements VisitableBuilder<ControllerRevision,ControllerRevisionBuilder>{
  public ControllerRevisionBuilder() {
    this(false);
  }
  public ControllerRevisionBuilder(Boolean validationEnabled) {
    this(new ControllerRevision(), validationEnabled);
  }
  public ControllerRevisionBuilder(ControllerRevisionFluent<?> fluent) {
    this(fluent, false);
  }
  public ControllerRevisionBuilder(ControllerRevisionFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ControllerRevision(), validationEnabled);
  }
  public ControllerRevisionBuilder(ControllerRevisionFluent<?> fluent,ControllerRevision instance) {
    this(fluent, instance, false);
  }
  public ControllerRevisionBuilder(ControllerRevisionFluent<?> fluent,ControllerRevision instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new ControllerRevision());

    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withData(instance.getData());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withRevision(instance.getRevision());
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withData(instance.getData());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withRevision(instance.getRevision());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ControllerRevisionBuilder(ControllerRevision instance) {
    this(instance,false);
  }
  public ControllerRevisionBuilder(ControllerRevision instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new ControllerRevision());

    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withData(instance.getData());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withRevision(instance.getRevision());
      this.withApiVersion(instance.getApiVersion());
      this.withData(instance.getData());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withRevision(instance.getRevision());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  ControllerRevisionFluent<?> fluent;
  Boolean validationEnabled;
  public ControllerRevision build() {
    ControllerRevision buildable = new ControllerRevision(fluent.getApiVersion(),fluent.buildData(),fluent.getKind(),fluent.buildMetadata(),fluent.getRevision());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
